# ByPassSafe <h1>

ByPassSafe é uma ferramente para gerenciamento de senhas, contruida em Python, durante a disciplina de Programação Orientada a Objetos 2

## Installation <h2>

~~~bash
pip install bypassafe
~~~

## Usage <h2>
Para executar, siga os seguintes passos:

~~~bash
Copy code
Python3 -m ByPassSafe
This will launch the password management tool and allow you to perform various operations.
~~~



### Getting Started <h3>

1. Instale a ferramenta executando o comando pip install bypasssafe
2. Execute a ferramente no CLI com python -m bypasssafe ou use de nossas funcionalidades importando a lib.
3. Siga as instruções para usar a lib de forma correta: Crie uma conta mestre, Acesse-a e cadastre sua conta das principais plataformas pra ter suas senhas sempre a mão, sem precisar decora-las, usando assim senhas muito mais complexas e seguras.


<h1>Contributing</h1>
Qualquer contribuição é bem-vinda e muito apreciada!!!

<h1>License</h1>
Licensa MIT padrão.